@@ -15,7 +15,7 @@ our @EXPORT_OK = (
 );
 our %EXPORT_TAGS = (all => \@EXPORT_OK);
 
-our $VERSION = "v6.15.0";
+our $VERSION = "v6.16.0";
 
 1;
 __END__
@@ -61,7 +61,7 @@ The documentation in this POD applies to all three adapter modules as well.
 This module is an implementation of L<Reactive Extensions|http://reactivex.io/> in Perl. It replicates the
 behavior of L<rxjs 6|https://www.npmjs.com/package/rxjs> which is the JavaScript implementation of ReactiveX.
 
-Currently 63 of the 100+ operators in rxjs are implemented in this module.
+Currently 67 of the 100+ operators in rxjs are implemented in this module.
 
 =head1 EXPORTABLE FUNCTIONS
 
@@ -338,6 +338,17 @@ Works like rxjs's "timer", except the parameter is in seconds instead of ms.
     # (pause 10 seconds) 0, 1, 2, 3, ... (every 1 second)
     rx_timer(10, 1)->subscribe($observer);
 
+=item rx_zip
+
+L<https://rxjs.dev/api/index/function/zip>
+
+    # [0, 0, 0], [1, 1, 1], [2, 2, 2], complete
+    rx_zip(
+        rx_interval(0.7)->pipe( op_take(3) ),
+        rx_interval(1),
+        rx_interval(2),
+    )->subscribe($observer);
+
 =back
 
 =head2 PIPEABLE OPERATORS
@@ -541,6 +552,16 @@ L<https://rxjs.dev/api/operators/distinctUntilKeyChanged>
         op_distinct_until_key_changed('name'),
     )->subscribe($observer);
 
+=item op_element_at
+
+L<https://rxjs.dev/api/operators/elementAt>
+
+    # 2, complete
+    rx_interval(0.7)->pipe(
+        op_take(5),
+        op_element_at(2, 9),
+    )->subscribe($observer);
+
 =item op_end_with
 
 L<https://rxjs.dev/api/operators/endWith>
@@ -550,6 +571,15 @@ L<https://rxjs.dev/api/operators/endWith>
         op_end_with(100, 200),
     )->subscribe($observer);
 
+=item op_every
+
+L<https://rxjs.dev/api/operators/every>
+
+    # 0, complete
+    rx_of(5, 10, 15, 18, 20)->pipe(
+        op_every(sub ($value, $idx) { $value % 5 == 0 }),
+    )->subscribe($observer);
+
 =item op_exhaust_map
 
 L<https://rxjs.dev/api/operators/exhaustMap>
@@ -710,6 +740,16 @@ L<https://rxjs.dev/api/operators/pluck>
         op_pluck('name', 'first'),
     )->subscribe($observer);
 
+=item op_reduce
+
+L<https://rxjs.dev/api/operators/reduce>
+
+    # (pause 6 seconds) 15, complete
+    rx_interval(1)->pipe(
+        op_take(6),
+        op_reduce(sub ($acc, $value, $idx) { $acc + $value }, 0),
+    )->subscribe($observer);
+
 =item op_ref_count
 
 L<https://rxjs.dev/api/operators/refCount>
