@@ -11,16 +11,17 @@ use RxPerl::ReplaySubject;
 
 use Carp 'croak';
 use Scalar::Util qw/ weaken blessed reftype /;
+use List::Util 'first';
 
 use Exporter 'import';
 our @EXPORT_OK = qw/
     rx_behavior_subject rx_combine_latest rx_concat rx_defer rx_EMPTY rx_fork_join rx_from rx_from_event
     rx_from_event_array rx_interval rx_merge rx_NEVER rx_observable rx_of rx_partition rx_race rx_range
-    rx_replay_subject rx_subject rx_throw_error rx_timer
+    rx_replay_subject rx_subject rx_throw_error rx_timer rx_zip
 /;
 our %EXPORT_TAGS = (all => \@EXPORT_OK);
 
-our $VERSION = "v6.15.0";
+our $VERSION = "v6.16.0";
 
 sub rx_observable;
 
@@ -532,4 +533,56 @@ sub rx_timer {
     });
 };
 
+sub rx_zip {
+    my @sources = @_;
+
+    return rx_observable->new(sub {
+        my ($subscriber) = @_;
+
+        my @sources_metadata = map {
+            +{
+                buffer    => [],
+                completed => 0,
+            };
+        } @sources;
+        my @own_subscriptions = map RxPerl::Subscription->new, @sources;
+
+        $subscriber->subscription->add(\@own_subscriptions);
+
+        for my $i (0 .. (@sources - 1)) {
+            my $own_subscriber = {
+                new_subscription => $own_subscriptions[$i],
+                next             => sub {
+                    my ($v) = @_;
+
+                    # push to buffer
+                    push @{$sources_metadata[$i]{buffer}}, $v;
+
+                    # if all buffers have elements in them:
+                    if (!first {!@{$_->{buffer}}} @sources_metadata) {
+                        my @next = map {shift @$_} map $_->{buffer}, @sources_metadata;
+                        $subscriber->{next}->(\@next) if defined $subscriber->{next};
+                        if (first {!@{$_->{buffer}} and $_->{completed}} @sources_metadata) {
+                            $subscriber->{complete}->() if defined $subscriber->{complete};
+                        }
+                    }
+                },
+                error            => sub {
+                    $subscriber->{error}->(@_) if defined $subscriber->{error};
+                },
+                complete         => sub {
+                    $sources_metadata[$i]{completed} = 1;
+                    if (!@{$sources_metadata[$i]{buffer}}) {
+                        $subscriber->{complete}->() if defined $subscriber->{complete};
+                    }
+                },
+            };
+
+            $sources[$i]->subscribe($own_subscriber);
+        }
+
+        return;
+    });
+}
+
 1;
