@@ -3,7 +3,7 @@ use strict;
 use warnings;
 
 use RxPerl::Operators::Creation qw/
-    rx_observable rx_subject rx_concat rx_of rx_interval rx_combine_latest rx_concat
+    rx_observable rx_subject rx_concat rx_of rx_interval rx_combine_latest rx_concat rx_throw_error
 /;
 use RxPerl::ConnectableObservable;
 use RxPerl::Utils qw/ get_timer_subs /;
@@ -16,14 +16,14 @@ use Exporter 'import';
 our @EXPORT_OK = qw/
     op_audit_time op_buffer op_buffer_count op_buffer_time op_catch_error op_combine_latest_with op_concat_map
     op_concat_with op_count op_debounce_time op_default_if_empty op_delay op_distinct_until_changed
-    op_distinct_until_key_changed op_end_with op_exhaust_map op_filter op_finalize op_first op_ignore_elements op_map
-    op_map_to op_merge_map op_multicast op_pairwise op_pluck op_ref_count op_repeat op_retry op_sample_time op_scan
-    op_share op_skip op_skip_until op_start_with op_switch_map op_take op_take_until op_take_while op_tap
-    op_throttle_time op_with_latest_from
+    op_distinct_until_key_changed op_element_at op_end_with op_every op_exhaust_map op_filter op_finalize op_first
+    op_ignore_elements op_map op_map_to op_merge_map op_multicast op_pairwise op_pluck op_reduce op_ref_count op_repeat
+    op_retry op_sample_time op_scan op_share op_skip op_skip_until op_start_with op_switch_map op_take op_take_until
+    op_take_while op_tap op_throttle_time op_with_latest_from
 /;
 our %EXPORT_TAGS = (all => \@EXPORT_OK);
 
-our $VERSION = "v6.15.0";
+our $VERSION = "v6.16.0";
 
 sub op_audit_time {
     my ($duration) = @_;
@@ -555,6 +555,45 @@ sub op_distinct_until_key_changed {
     }),
 }
 
+sub op_element_at {
+    my ($index, $default) = @_;
+    my $has_default = @_ >= 2;
+    $index = int $index;
+
+    return sub {
+        my ($source) = @_;
+
+        $index >= 0 or return rx_throw_error('ArgumentOutOfRangeError');
+
+        return rx_observable->new(sub {
+            my ($subscriber) = @_;
+
+            my $i = 0;
+            my $own_subscriber = {
+                %$subscriber,
+                next     => sub {
+                    if ($i++ == $index) {
+                        $subscriber->{next}->(@_) if defined $subscriber->{next};
+                        $subscriber->{complete}->() if defined $subscriber->{complete};
+                    }
+                },
+                complete => sub {
+                    if ($has_default) {
+                        $subscriber->{next}->($default) if defined $subscriber->{next};
+                        $subscriber->{complete}->() if defined $subscriber->{complete};
+                    } else {
+                        $subscriber->{error}->('ArgumentOutOfRangeError') if defined $subscriber->{error};
+                    }
+                },
+            };
+
+            $source->subscribe($own_subscriber);
+
+            return;
+        });
+    };
+}
+
 sub op_end_with {
     my (@values) = @_;
 
@@ -568,6 +607,39 @@ sub op_end_with {
     }
 }
 
+sub op_every {
+    my ($predicate) = @_;
+
+    return sub {
+        my ($source) = @_;
+
+        return rx_observable->new(sub {
+            my ($subscriber) = @_;
+
+            my $idx = 0;
+            my $own_subscriber = {
+                %$subscriber,
+                next     => sub {
+                    my ($v) = @_;
+                    local $_ = $v;
+                    if (! $predicate->($v, $idx++)) {
+                        $subscriber->{next}->(0) if defined $subscriber->{next};
+                        $subscriber->{complete}->() if defined $subscriber->{complete};
+                    }
+                },
+                complete => sub {
+                    $subscriber->{next}->(1) if defined $subscriber->{next};
+                    $subscriber->{complete}->() if defined $subscriber->{complete};
+                },
+            };
+
+            $source->subscribe($own_subscriber);
+
+            return;
+        });
+    };
+}
+
 sub op_exhaust_map {
     my ($observable_factory) = @_;
 
@@ -889,6 +961,46 @@ sub op_pluck {
     };
 }
 
+sub op_reduce {
+    my ($accumulator, @seed) = @_;
+
+    return sub {
+        my ($source) = @_;
+
+        return rx_observable->new(sub {
+            my ($subscriber) = @_;
+
+            my $got_first = @seed;
+            my $acc;
+            $acc = $seed[0] if $got_first;
+
+            my $idx = 0;
+            my $own_subscriber = {
+                %$subscriber,
+                next     => sub {
+                    my ($v) = @_;
+
+                    if ($got_first) {
+                        my $ok = eval { $acc = $accumulator->($acc, $v, $idx++); 1 };
+                        $ok or $subscriber->{error}->($@) if defined $subscriber->{error};
+                    } else {
+                        $acc = $v;
+                        $got_first = 1;
+                    }
+                },
+                complete => sub {
+                    $subscriber->{next}->($acc) if $got_first and defined $subscriber->{next};
+                    $subscriber->{complete}->() if defined $subscriber->{complete};
+                },
+            };
+
+            $source->subscribe($own_subscriber);
+
+            return;
+        });
+    };
+}
+
 sub op_ref_count {
     return sub {
         my ($source) = @_;
